summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rw-r--r--tests/regressiontests/model_inheritance_regress/tests.py34
1 files changed, 28 insertions, 6 deletions
diff --git a/tests/regressiontests/model_inheritance_regress/tests.py b/tests/regressiontests/model_inheritance_regress/tests.py
index 569cef5845..dac2cb5de5 100644
--- a/tests/regressiontests/model_inheritance_regress/tests.py
+++ b/tests/regressiontests/model_inheritance_regress/tests.py
@@ -3,12 +3,16 @@ Regression tests for Model inheritance behaviour.
"""
import datetime
+from operator import attrgetter
+
from django.test import TestCase
-from regressiontests.model_inheritance_regress.models import (
- Place, Restaurant, ItalianRestaurant, ParkingLot, ParkingLot2,
- ParkingLot3, Supplier, Wholesaler, Child, SelfRefChild, ArticleWithAuthor,
- M2MChild, QualityControl, DerivedM, Person, BirthdayParty, BachelorParty,
- MessyBachelorParty, InternalCertificationAudit)
+
+from models import (Place, Restaurant, ItalianRestaurant, ParkingLot,
+ ParkingLot2, ParkingLot3, Supplier, Wholesaler, Child, SelfRefParent,
+ SelfRefChild, ArticleWithAuthor, M2MChild, QualityControl, DerivedM,
+ Person, BirthdayParty, BachelorParty, MessyBachelorParty,
+ InternalCertificationAudit)
+
class ModelInheritanceTest(TestCase):
def test_model_inheritance(self):
@@ -355,7 +359,10 @@ class ModelInheritanceTest(TestCase):
self.assertEqual(parties, [bachelor, messy_parent])
def test_11369(self):
- """verbose_name_plural correctly inherited from ABC if inheritance chain includes an abstract model."""
+ """
+ verbose_name_plural correctly inherited from ABC if inheritance chain
+ includes an abstract model.
+ """
# Regression test for #11369: verbose_name_plural should be inherited
# from an ABC even when there are one or more intermediate
# abstract models in the inheritance chain, for consistency with
@@ -364,3 +371,18 @@ class ModelInheritanceTest(TestCase):
InternalCertificationAudit._meta.verbose_name_plural,
u'Audits'
)
+
+ def test_inherited_nullable_exclude(self):
+ obj = SelfRefChild.objects.create(child_data=37, parent_data=42)
+ self.assertQuerysetEqual(
+ SelfRefParent.objects.exclude(self_data=72), [
+ obj.pk
+ ],
+ attrgetter("pk")
+ )
+ self.assertQuerysetEqual(
+ SelfRefChild.objects.exclude(self_data=72), [
+ obj.pk
+ ],
+ attrgetter("pk")
+ )